Diskgroup Commands
Use commands with the diskgroup keyword to manage Oracle ASM disk groups.
You can add, modify, list the configuration of, enable, disable, start, stop, obtain the status of, and remove Oracle ASM disk groups.
srvctl disable diskgroup
Disables a specific disk group on a number of specified nodes.
Syntax
srvctl disable diskgroup -diskgroup diskgroup_name [-node "node_list"]
Parameters
Table: srvctl disable diskgroup Command Parameters
| Parameter | Description |
|---|---|
-diskgroup diskgroup_name | Specify the name of the Oracle ASM disk group you want to disable. |
-node " node_list " | Optionally, you can specify a comma-delimited list of node names enclosed in double quotation marks ( Note: You can only use this parameter with Oracle Clusterware. |
Example
The following example disables the Oracle ASM disk group, dgroup1, on two nodes in a cluster, mynode1 and mynode2:
$ srvctl disable diskgroup -diskgroup dgroup1 -node "mynode1,mynode2"
srvctl enable diskgroup
Enables a specific disk group on a number of specified nodes.
Syntax
srvctl enable diskgroup -diskgroup diskgroup_name [-node "node_list"]
Parameters
Table: srvctl enable diskgroup Command Parameters
| Parameter | Description |
|---|---|
-diskgroup diskgroup_name | Specify the name of the Oracle ASM disk group you want to enable. |
-node " node_list " | Optionally, you can specify a comma-delimited list of node names enclosed in double quotation marks ( Note: You can only use this parameter with Oracle Clusterware. |
Example
The following example enables the diskgroup1 Oracle ASM disk group on nodes mynode1 and mynode2:
$ srvctl enable diskgroup -diskgroup diskgroup1 -node "mynode1,mynode2"
srvctl predict diskgroup
Predicts the consequences of an Oracle ASM disk group failure.
Syntax
srvctl predict diskgroup -diskgroup diskgroup_name [-verbose]
Usage Notes
Specify the name of the Oracle ASM disk group for which you want to evaluate a failure. Optionally, you can use the -verbose parameter top print detailed output.
srvctl remove diskgroup
Removes a specific Oracle ASM disk group resource from Oracle Clusterware or Oracle Restart.
Syntax
srvctl remove diskgroup -diskgroup diskgroup_name [-force]
Usage Notes
Specify the name of the Oracle ASM disk group you want to remove. Optionally, you can use the -force parameter to ignore any dependencies and forcibly remove the disk group.
Example
The following example forcibly removes the DG1 Oracle ASM disk group:
$ srvctl remove diskgroup -diskgroup DG1 -force
srvctl start diskgroup
Starts a specific Oracle ASM disk group resource on a number of specified nodes.
Syntax
srvctl start diskgroup -diskgroup diskgroup_name [-node "node_list"]
Parameters
Table: srvctl start diskgroup Command Parameters
| Parameter | Description |
|---|---|
-diskgroup diskgroup_name | Specify the name of the Oracle ASM disk group you want to start. |
-node " node_list " | Optionally, you can specify a comma-delimited list of node names enclosed in double quotation marks ( Note: You can only use this parameter with Oracle Clusterware. |
Example
The following example starts the diskgroup1 Oracle ASM disk group on the nodes mynode1 and mynode2:
$ srvctl start diskgroup -diskgroup diskgroup1 -node "mynode1,mynode2"
srvctl status diskgroup
Displays the status of a specific disk group on a number of specified nodes.
Syntax
srvctl status diskgroup -diskgroup diskgroup_name [-node "node_list"]
[-detail] [-verbose]
Parameters
Table: srvctl status diskgroup Command Parameters
| Parameter | Description |
|---|---|
-diskgroup diskgroup_name | Specify the name of the Oracle ASM disk group for which you want to display the status. |
-node " node_list " | Optionally, you can specify a comma-delimited list of node names on which to check status of an Oracle ASM disk group. Note: You can only use this parameter with Oracle Clusterware. |
-detail | Optionally, you can use this parameter to display detailed status information for the Oracle ASM disk group. |
-verbose | Optionally, you can use this parameter to display verbose output. |
Examples
The following example displays the status of the dgrp1 Oracle ASM disk group:
$ srvctl status diskgroup -diskgroup dgrp1 -node "mynode1,mynode2" -detail
srvctl stop diskgroup
Stops a specific Oracle ASM disk group resource on a number of specified nodes.
Syntax
srvctl stop diskgroup -diskgroup diskgroup_name [-node "node_list"] [-force]
Parameters
Table: srvctl stop diskgroup Command Parameters
| Parameter | Description |
|---|---|
-diskgroup diskgroup_name | Specify the name of the Oracle ASM disk group you want to stop. |
-node " node_list " | Optionally, you can specify a comma-delimited list of node names enclosed in double quotation marks ( Note: You can only use this parameter with Oracle Clusterware. |
-force | Optionally, you can use this parameter to perform a forceful dismount. While this parameter does not stop the databases that depend on the disk group you are stopping, it still may cause those databases to fail. |
Example
The following command stops the diskgroup1 Oracle ASM disk group on the two nodes mynode1 and mynode2:
$ srvctl stop diskgroup -diskgroup diskgroup1 -node "mynode1,mynode2" -force